import "./App.css";
// https://socket.dev/npm/package/react-hook-speech-to-text
import useSpeechToText from "react-hook-speech-to-text";
import micIcon from "./assets/1608550_microphone_icon.png";
import useFetch from "./hooks/useFetch";
import ProductListItem from "./components/productListItem";
import { useEffect, useState } from "react";

// const tts = require("node-google-text-to-speech");

// tts.translate("en", "dog", function (result) {
//   console.log(result);
//   if (result.success) {
//     //check for success
//     const response = { audio: result.data };
//     socket.emit("ttsResult", response); //emit the audio to client
//   }
// });

function App() {
  const {
    error,
    interimResult,
    isRecording,
    results,
    setResults,
    startSpeechToText,
    stopSpeechToText,
  } = useSpeechToText({
    continuous: true,
    useLegacyResults: false,
  });

  const {
    get,
    loading,
    error: responseError,
    response,
  } = useFetch(`${import.meta.env.VITE_API_ENDPOINT}/todos`);

  const [currentProductId, setCurrentProductId] = useState<null | number>(null);

  useEffect(() => {
    if (results.length > 0) {
      (async () => {
        await get();
      })();
    }
  }, [results]);

  // display: flex;
  // flex-direction: column;
  // align-items: center;

  if (error) return <p>Web Speech API is not available in this browser 🤷‍</p>;
  console.log("response: ", response);
  console.log("responseError: ", responseError);

  const text = results.length > 0 && results[results.length - 1].transcript;
  const msg = new SpeechSynthesisUtterance();

  const speak = (textToSay) => {
    const msg = new SpeechSynthesisUtterance();
    msg.text = textToSay;
    window.speechSynthesis.speak(msg);
  };

  return (
    <>
      <div>
        <h3>Please, tell us what are you looking for?</h3>

        <span>Click and hold to speak!</span>
      </div>
      <div className={`mt-5 flex flex-col items-center`}>
        <div
          onMouseDown={() => {
            startSpeechToText();
          }}
          onMouseUp={stopSpeechToText}
          className={`w-16 border border-solid rounded-full cursor-pointer p-2.5  ${
            isRecording && "speaking"
          }`}
        >
          <img src={micIcon}></img>
        </div>
        {isRecording && <span className="text-sm">Listening...</span>}
        <ul className="mt-5 italic">
          {text && `Showing results for: ${text}`}
          {/* {results.map(result => {
            return (
              <li key={result.timestamp}>{`Looking for: "${result.transcript}"`}</li>
            )
          })} */}
          {/* {interimResult && <li>{interimResult}</li>} */}
        </ul>

        {loading && `Hold on a bit please!`}

        {!loading && !responseError && response && response.length > 0 && (
          <div id="findings-section">
            {response.map((content) => {
              return (
                <ProductListItem
                  expandCallback={(pid: number) => setCurrentProductId(pid)}
                  current={currentProductId}
                  category={content.category}
                  price={content.price}
                  rating={content.rating}
                  id={content.id}
                  title={content.title}
                  description={content.description}
                  imgLink={content.image}
                ></ProductListItem>
              );
            })}
          </div>
        )}
      </div>
    </>
  );
}

export default App;
