import React, { useEffect, useRef, useState } from "react";
import useFetch from "../../hooks/useFetch";
import { Select, Space } from "antd";
import { CloseOutlined } from "@ant-design/icons";

const shouldUpdate = (prevProps, nextProps) => {
  // Custom comparison logic based on prevProps and nextProps
  // Return true if props are equal, return false otherwise
  return !prevProps.id === nextProps.id;
};

const ProductListItem = React.memo(
  (props: {
    id: number;
    title: string;
    description: string;
    imgLink: string;
    current: number | null;
    category: string;
    price: number;
    rating: {
      rate: number;
      count: number;
    };
    expandCallback(id: number): void;
  }) => {

    const currentElement = useRef(null);
    const {
      get,
      loading: loadingImg,
      error: responseError,
      response: responseImg,
    } = useFetch(`http://localhost:5000/`);
    console.log("responseImg: ", responseImg);
    const [displayModal, setDisplayModal] = useState(false);
    useEffect(() => {
      debugger;
      const newHeight =
        props.current && props.current == props.id ? `auto` : `8rem`;
      if (currentElement.current)
        currentElement.current.setAttribute("style", `height:${newHeight}`);
    }, [props]);

    const callPythonApp = (startingPointId:string) => {
      get(`startingPointId=${startingPointId}`);
    };

    const showModal = () => {
      setDisplayModal(!displayModal);
    };

    const handleChange = (value: string) => {
      callPythonApp(value);
    };

    return (
      <div
        id={props.id.toString()}
        className={`flex tran`}
        onClick={() => {
          // const newHeight = (props.current && props.current == props.id) ? `auto` : `8rem`;
          // if(currentElement.current) currentElement.current.setAttribute("style",`height:${newHeight}`);
          props.expandCallback(props.id);
        }}
        ref={currentElement}
      >
        {
          displayModal && (
            <div>
              <div
                onClick={showModal}
                className="absolute top-0 left-0 w-full h-full bg-[#686868d1]"
              ></div>
              <div className="fixed w-[80%] h-[80%] top-[10%] left-[10%] bg-white	border rounded overflow-scroll">
                <div className="absolute right-0 mr-3	mt-2">
                  <CloseOutlined onClick={showModal} />
                </div>
                <div className="mt-6">
                  <h3>Select the Starting point</h3>
                  <span>
                    Please chose the entrance or place you are more close to
                  </span>
                </div>
                <div>
                  <Select
                    defaultValue="Select the entrance"
                    style={{ width: 260, marginTop: "1%" }}
                    onChange={handleChange}
                    loading={loadingImg}
                    options={[
                      { value: "SP1", label: "ENTRANCE 1" },
                      { value: "SP2", label: "ENTRANCE 2" },
                      { value: "SP3", label: "ENTRANCE 3" },
                      { value: "SP4", label: "ENTRANCE 4" },
                      { value: "SP5", label: "ENTRANCE 5" },
                      { value: "SP6", label: "ENTRANCE 6" },
                    ]}
                  />
                  {responseImg && responseImg.image && (
                    <img
                      className="max-w-screen-md	ml-auto	mr-auto mt-8 w-full"
                      src={`data:image/jpg;base64,${responseImg.image}`}
                    />
                  )}
                </div>
              </div>
            </div>
          )
          // responseImg && responseImg.image && (
          //   <img src={`data:image/jpg;base64,${responseImg.image}`}/>
          // )
        }
        <div className="mt-auto mb-auto ml-2 mr-2">
          <div className="w-16">
            <img src={props.imgLink}></img>
          </div>
        </div>
        <div className="flex flex-col p-2 pb-3">
          <div className="text-left font-semibold" id="header">
            <span>{props.title}</span>
          </div>
          <div id="content" className="overflow-scroll text-left text-sm">
            <span>{props.description}</span>
            {props.current && props.current == props.id && (
              <div className="flex flex-col">
                <div>
                  <span className="font-semibold">Category: </span>{" "}
                  <span>{props.category}</span>{" "}
                </div>
                <div>
                  <span className="font-semibold">Price: </span>{" "}
                  <span>{props.price}</span>
                </div>
                <div>
                  <span className="font-semibold">Rating: </span>{" "}
                  <span>{props.rating.rate}</span>
                </div>
                <div>
                  <span
                    onClick={showModal}
                    className="font-semibold text-blue-web"
                  >
                    Click here to get the location
                  </span>

                  <></>
                </div>
              </div>
            )}
          </div>
        </div>
      </div>
    );
  },
  shouldUpdate
);

export default ProductListItem;
