import geopandas as gpd
import matplotlib.pyplot as plt
import matplotlib.font_manager as fm

title_font = fm.FontProperties(family='Arial', style='normal', size=12, weight='normal', stretch='normal')

# Step 1: Read the GeoJSON file using GeoPandas
# https://en.wikipedia.org/wiki/GeoJSON
geojson_file = "./floorPlan.json"

gdf = gpd.read_file(geojson_file)

# How to place the geometrycs in a non empty png with the plan/map of the store.

# Step 2: Create a plot using Matplotlib
fig, ax = plt.subplots(figsize=(10, 10))
gdf.plot(ax=ax)


ax.set_title('Store floor map', fontproperties=title_font)

gdf.apply(lambda x:
        ax.annotate(text=x['prop0'], 
        xy=(x.geometry.centroid.x, x.geometry.centroid.y+0.1),
        ha='center')  
        if x['type']=='gate' else 
        ax.annotate(text=x['prop0'], 
        xy=(x.geometry.centroid.x, x.geometry.centroid.y),
        bbox=dict(boxstyle='round', color='k', fc='w', alpha=0.8),
        ha='center'), 
        axis=1)
        
# Step 3: Save the plot as a PNG file
output_png = "sample-map.png"
plt.savefig(output_png, dpi=300, bbox_inches='tight')

# Step 4: Show the plot (optional)
plt.show()

# Step 5: Close the plot
plt.close()

